===============================================================
PyFaultDiagnosisToolbox - A Python toolbox for fault diagnosis
===============================================================
Fault Diagnosis Toolbox is a Python package for analysis and design of fault diagnosis systems for dynamic systems, 
primarily described by differential-algebraic equations. Key features of the toolbox are extensive support for 
structural analysis of large-scale dynamic models, fault isolability analysis, sensor placement analysis, 
and code generation in C/C++ and Python.

The toolbox is an adaptation of our Matlab toolbox that can be downloaded from https://faultdiagnosistoolbox.github.io where you 
can also find `documentation <https://faultdiagnosistoolbox.github.io/_releases/user-manual_2018-12-09.pdf>`_. The latest version of the python package can always be pip-installed.

For a quick introduction, see the `use case <https://faultdiagnosistoolbox.github.io/usecase/>`_ where an industrial 
size example, an automotive engine, is analyzed, C-code for residual generators is generated, and the resulting 
diagnosis system is evaluated on test-cell measurements from our engine laboratory.

If you use this toolbox in your research, please cite any relevant papers of ours, see list of 
`references <https://faultdiagnosistoolbox.github.io/references>`_ for details.

The toolbox is freely available under a MIT license. 

